BGF_defaultcolors: The default color set to be used by 'bgf_plot'

BGF_defaultcolorsR Documentation

The default color set to be used by bgf_plot

Description

The default color set used when plotting a BGF using the advanced plotting functions. It contains 3 * 8 = 24 colors.

Usage

BGF_defaultcolors

Format

An object of class character of length 24.


bgfanalyzer documentation built on Sept. 26, 2026, 5:07 p.m.