| LabscaleBiogasLayout | R Documentation |
The data set contains a reactor layout of a lab scale biogas fermentation conducted with the AMPTS II system (BPC, Lund, Sweden).
LabscaleBiogasLayout
An object of class character of length 15.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.