calc_FR_time: Calculate Fermentation Time

View source: R/calc_FR_time.R

calc_FR_timeR Documentation

Calculate Fermentation Time

Description

Calculates the fermentation time for a minimal biogas fermentation data set

Usage

calc_FR_time(standardReport, time_col, ...)

Arguments

standardReport

a data.frame with at least one column representing a series of time stamps (%y-%m-%d %H:%M:%S)

time_col

numeric. indicates which column of standard report is used to calculate the fermentation time

...

further arguments passed to difftime

Value

A data.frame with an additional ⁠$time⁠ column

Examples

# import example biogas fermentation data
stRep<-import_standard_record(
      ipath = base::system.file("extdata","Fermentation_B.tsv",package = "bgfanalyzer"),
      header=TRUE,
      dec=".",
      sep="\t")

# calculating the fermentation time adds a new column ($time) to the input data.frame
stRep_FRT<-calc_FR_time(stRep,1,units="hours")


bgfanalyzer documentation built on Sept. 26, 2026, 5:07 p.m.