| new_BGF | R Documentation |
Builds a BGF object from input parameters.
new_BGF(
name,
ProcessTemp,
InocToSubRatio,
ReactorLayout,
BlankLabel,
MeasurementType = NA
)
name |
A character vector specifying the name of the new BGF object |
ProcessTemp |
The process temperature of the fermentation(s) to be stored in the BGF object |
InocToSubRatio |
The inoculum to substrate ratio (= inoculation strength) of the fermentation(s) to be stored in the BGF object |
ReactorLayout |
A character vector providing the reactor layout, e.g. the grouping factor used for plotting and yield calculation of fermentation(s) in a BGF object |
BlankLabel |
A character string indicating which group in ReactorLayout is the inoculum used for net gas/ yield calculation |
MeasurementType |
An optional character string indicating the measurement type of the BGF object to be created |
This function serves as a base constructor to create a new BGF object. The constructor first checks if all required input variables have the correct data type, then a minimal BGF object is created thereof. All BGFs object share the structure of such a minimal BGF object, e.g. a list with at least three elements:
ExpParam: A list that stores information on the BGF object itself, as well as meta data all fermentations of the object have in common. For example, the input variables name, ProcessTemp, InocToSubRatio and MeasurementType are stored as elements in this list
metaData: A matrix with one row for each fermentation of the BGF object. It is created from the input variables ReactorLayout and BlankLabel. The first column of that matrix provides the ReactorLayout of the corresponding fermentation/ row. The second holds the information whether this layout is the specified BlankLabel or not. The third column enables to classify a fermentation/ row as excluded. Excluded fermentations are not used for yield statistics and can be hidden in plots
BioGasData: A matrix in which experimental data of each fermentation is stored. Upon object creation, all values are set NA. Initially, seven columns are created but further column can be added via dedicated methods or R base syntax.
An R object of class BGF
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.