plot.BGF: Plot a Biogas Fermentation

View source: R/plot.BGF.R

plot.BGFR Documentation

Plot a Biogas Fermentation

Description

Default plot method for a BGF.

Usage

## S3 method for class 'BGF'
plot(
  x,
  xlab = "Time",
  ylab = "Volume [Nml]",
  main = paste0("Raw exhaust gas volume plot of ", x$ExpParam$name),
  ...
)

Arguments

x

An object of class BGF

xlab, ylab, main

character strings specifying the title of the x-axis, the y-axis or the plot itself, respectively.

...

arguments to be passed to methods, such as graphical parameters (see par). Many methods will accept the following arguments:

type

what type of plot should be drawn. Possible types are

  • "p" for points,

  • "l" for lines,

  • "b" for both,

  • "c" for the lines part alone of "b",

  • "o" for both ‘overplotted’,

  • "h" for ‘histogram’ like (or ‘high-density’) vertical lines,

  • "s" for stair steps,

  • "S" for other steps, see ‘Details’ below,

  • "n" for no plotting.

All other types give a warning or an error; using, e.g., type = "punkte" being equivalent to type = "p" for S compatibility. Note that some methods, e.g. plot.factor, do not accept this.

main

an overall title for the plot: see title.

sub

a subtitle for the plot: see title.

xlab

a title for the x axis: see title.

ylab

a title for the y axis: see title.

asp

the y/x aspect ratio, see plot.window.

Details

Creates a raw exhaust gas volume plot of the fermentations stored in a BGF object.

Value

A plot of exhaust gas volumes


bgfanalyzer documentation built on Sept. 26, 2026, 5:07 p.m.