| calc_FR_time | R Documentation |
Calculates the fermentation time for a minimal biogas fermentation data set
calc_FR_time(standardReport, time_col, ...)
standardReport |
a data.frame with at least one column representing a series of time stamps (%y-%m-%d %H:%M:%S) |
time_col |
numeric. indicates which column of standard report is used to calculate the fermentation time |
... |
further arguments passed to |
A data.frame with an additional $time column
# import example biogas fermentation data
stRep<-import_standard_record(
ipath = base::system.file("extdata","Fermentation_B.tsv",package = "bgfanalyzer"),
header=TRUE,
dec=".",
sep="\t")
# calculating the fermentation time adds a new column ($time) to the input data.frame
stRep_FRT<-calc_FR_time(stRep,1,units="hours")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.